@@ -13,6 +13,7 @@ fi
 
 SRC="src/tk${TCLVERS}.tar.gz"
 SRCURL="http://prdownloads.sourceforge.net/tcl/tk${TCLVERS}-src.tar.gz"
+SRCHASH='-'
 BUILDDIR="$(pwd)/build/tk${TCLVERS}"
 PATCHDIR="$(pwd)/patches"
 OUTDIR="$(pwd)/out"
@@ -20,6 +21,12 @@ INSTDIR="$(pwd)/inst"
 PATCHSCRIPTDIR="$(pwd)/patchscripts"
 export SRC SRCURL BUILDDIR PATCHDIR OUTDIR INSTDIR PATCHSCRIPTDIR
 
+case "${TCLVERS}" in
+	8.6.4)
+		SRCHASH='08f99df85e5dc9c4271762163c6aabb962c8b297dc5c4c1af8bdd05fc2dd26c1'
+		;;
+esac
+
 # Set configure options for this sub-project
 LDFLAGS="${LDFLAGS} ${KC_TK_LDFLAGS}"
 CFLAGS="${CFLAGS} ${KC_TK_CFLAGS}"
@@ -81,11 +88,11 @@ if [ ! -f "${SRC}" ]; then
 			mkdir "${workdir}" || exit 1
 			cd "${workdir}" || exit 1
 
-			wget -O "tmp-tk.tar.gz" "http://core.tcl.tk/tk/tarball/tk-fossil.tar.gz?uuid=${FOSSILTAG}" || rm -f 'tmp-tk.tar.gz'
+			download "http://core.tcl.tk/tk/tarball/tk-fossil.tar.gz?uuid=${FOSSILTAG}" "tmp-tk.tar.gz" - || rm -f 'tmp-tk.tar.gz'
 			gzip -dc "tmp-tk.tar.gz" | tar -xf - || rm -f 'tmp-tk.tar.gz'
 
 			if [ ! -s 'tmp-tk.tar.gz' ]; then
-				wget -O "tmp-tk.tar.gz" "http://core.tcl.tk/tk/tarball/tk-fossil.tar.gz?uuid=${FOSSILDATE}" || rm -f 'tmp-tk.tar.gz'
+				download "http://core.tcl.tk/tk/tarball/tk-fossil.tar.gz?uuid=${FOSSILDATE}" "tmp-tk.tar.gz" - || rm -f 'tmp-tk.tar.gz'
 				gzip -dc "tmp-tk.tar.gz" | tar -xf -
 			fi
 
@@ -98,9 +105,7 @@ if [ ! -f "${SRC}" ]; then
 		)
 	else
 		if [ ! -d 'buildsrc' ]; then
-			rm -f "${SRC}.tmp"
-			wget -O "${SRC}.tmp" "${SRCURL}" || exit 1
-			mv "${SRC}.tmp" "${SRC}"
+			download "${SRCURL}" "${SRC}" "${SRCHASH}" || exit 1
 		fi
 	fi
 fi
